Class: extensible - LinkML Model

# Class: extensible

mixin for classes that support extension

URI: linkml:Extensible

## Mixin for

- Element (mixin) - a named element in the model
- PermissibleValue (mixin) - a permissible value, accompanied by intended text and an optional mapping to a concept URI
- UniqueKey (mixin) - a collection of slots whose values uniquely identify an instance of a class

## Referenced by Class

## Attributes

### Own

- extensions 0..*
  - Description: a tag/text tuple attached to an arbitrary element
  - Range: Extension